pub struct WakeupReason(/* private fields */);Expand description
The source(s) that caused the most recent wakeup from sleep.
Returned by wakeup_cause. This is a thin wrapper around the set of WakeupSources that
were reported by the hardware. The set is empty if the chip was not woken from sleep.
Note that the available sources depend on the target chip.
Implementations
Sourceimpl WakeupReason
impl WakeupReason
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the chip was not woken from sleep by any source.
Sourcepub fn contains(&self, source: WakeupSource) -> bool
pub fn contains(&self, source: WakeupSource) -> bool
Returns true if the given source caused the most recent wakeup.
Sourcepub fn iter(&self) -> impl Iterator<Item = WakeupSource>
pub fn iter(&self) -> impl Iterator<Item = WakeupSource>
Returns an iterator over the sources that caused the most recent wakeup.